TimelineExportProgress class
A snapshot of export progress emitted on NativeTimelinePlayer.exportProgress.
- Annotations
Constructors
- TimelineExportProgress({required double progress, required TimelineExportState state})
-
Creates a TimelineExportProgress with an explicit
progressandstate.const - TimelineExportProgress.fromMap(Map map)
-
factory
- TimelineExportProgress.idle()
-
Convenience constructor for the initial idle state.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- progress → double
-
Normalised completion ratio in the range
[0.0, 1.0].final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TimelineExportState
-
Current phase of the export operation.
final
Methods
-
copyWith(
{double? progress, TimelineExportState? state}) → TimelineExportProgress -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override