MethodChannelVideoUltraPlayer class
The default VideoUltraPlayerPlatform implementation that communicates with native code via a Flutter MethodChannel and EventChannel.
- Inheritance
-
- Object
- PlatformInterface
- VideoUltraPlayerPlatform
- MethodChannelVideoUltraPlayer
Constructors
Properties
- eventChannel → EventChannel
-
final
- exportEventChannel → EventChannel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
int textureId) → Future< void> -
override
-
exportCurrentTimeline(
int textureId, {String? outputPath}) → Future< String> -
Exports the currently loaded (and edited) timeline without requiring
a separate clip list. Preview and export share the same native state.
override
-
exportProgress(
) → Stream< TimelineExportProgress> -
override
-
exportTimeline(
List< Map< clips, {String? outputPath, Map<String, dynamic> >String, dynamic> ? config}) → Future<String> -
override
-
generateThumbnails(
String videoPath, List< int> timestampsMs, {int width = 120}) → Future<List< String> > -
Extracts and caches thumbnail frames from
videoPathat each timestamp intimestampsMs(milliseconds) and returns a list of absolute file-system paths to the cached JPEG images.override -
insertClip(
int textureId, int atIndex, Map< String, dynamic> clip) → Future<void> -
Inserts
clipat positionatIndexin the timeline.override -
load(
List< Map< clips, {Map<String, dynamic> >String, dynamic> ? config}) → Future<int> -
override
-
moveClip(
int textureId, int fromIndex, int toIndex) → Future< void> -
Moves the clip at
fromIndextotoIndex.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
int textureId) → Future< void> -
override
-
play(
int textureId) → Future< void> -
override
-
redo(
int textureId) → Future< void> -
Reapplies the next edit-model snapshot after an undo.
override
-
removeAudioTrack(
int textureId) → Future< void> -
Removes the external audio track from the loaded timeline.
override
-
removeClip(
int textureId, int clipIndex) → Future< void> -
Removes the clip at
clipIndexfrom the timeline.override -
replaceClip(
int textureId, int clipIndex, Map< String, dynamic> clip) → Future<void> -
Replaces the clip at
clipIndexwithclip.override -
seekTo(
int textureId, Duration position) → Future< void> -
override
-
seekToClip(
int textureId, int clipIndex) → Future< void> -
override
-
setAudioTrack(
int textureId, Map< String, dynamic> track) → Future<void> -
Overlays an external audio track on the loaded timeline.
override
-
setClipAlignment(
int textureId, int clipIndex, double x, double y) → Future< void> -
override
-
setClipSpeed(
int textureId, int clipIndex, double speed) → Future< void> -
Sets the playback speed of the clip at
clipIndextospeed.override -
setVolume(
int textureId, double volume) → Future< void> -
override
-
splitClip(
int textureId, int clipIndex, int atLocalPositionMs) → Future< void> -
Splits the clip at
clipIndexatatLocalPositionMsmilliseconds from its trim-start, producing two clips in its place.override -
stateStream(
int textureId) → Stream< TimelinePlayerState> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
trimClip(
int textureId, int clipIndex, {int? trimStartMs, int? trimEndMs}) → Future< void> -
Adjusts the trim in/out points of the clip at
clipIndex.override -
undo(
int textureId) → Future< void> -
Restores the previous edit-model snapshot for the loaded timeline.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited